import HawAPIOptions from './HawAPIOptions';
import { EndpointType } from './enums/EndpointType';
import { Filters, Pageable } from './filters';
import { APIInfoModel, ActorSocialModel, BaseModel, BaseTranslation, RequestResult } from './models';
/**
 * The HawAPI client.
 */
export default class HawAPIClient {
    options: HawAPIOptions;
    headers: HeadersInit;
    request: RequestInit;
    constructor(options?: HawAPIOptions);
    /**
     * Method to test API connection
     * @returns If connected. An {@link string} with 'Ping' value
     */
    ping(): Promise<string>;
    /**
     * Method to get all API informations
     * @returns An new {@link APIInfoModel}
     */
    getInfo(): Promise<APIInfoModel>;
    /**
     * Method to get all client options
     * @returns
     */
    getOptions(): Promise<HawAPIOptions>;
    /**
     * Method that get all items
     * @param target The target name
     * @param filters
     * @param pageable
     * @returns An new {@link RequestResult} with all target items
     */
    getAll<T extends BaseModel>(target: EndpointType, filters?: Filters | null, pageable?: Pageable | null): Promise<RequestResult<T[]>>;
    /**
     * Method that get a single item
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with specific target item
     */
    getBy<T extends BaseModel>(target: EndpointType, uuid: string): Promise<RequestResult<T>>;
    /**
     * Method that get a single random item
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with random target item
     */
    getRandom<T extends BaseModel>(target: EndpointType): Promise<RequestResult<T>>;
    /**
     * Method that get all item translations
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with all target item translations
     */
    getAllTranslations<T extends BaseTranslation>(target: EndpointType, uuid: string): Promise<RequestResult<T[]>>;
    /**
     * Method that get a single item
     * @param target The target name
     * @param uuid The target uuid
     * @param language The target translation language
     * @returns An new {@link RequestResult} with specific target item translation
     */
    getTranslationBy<T extends BaseTranslation>(target: EndpointType, uuid: string, language: string): Promise<RequestResult<T>>;
    /**
     * Method that get a single random item translation
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with random target item translation
     */
    getRandomTranslation<T extends BaseModel>(target: EndpointType, uuid: string): Promise<RequestResult<T>>;
    /**
     * Method that get all actor socials
     * @param uuid The actor uuid
     * @returns An new {@link RequestResult} with all actor socials
     */
    getAllSocials(uuid: string): Promise<RequestResult<ActorSocialModel[]>>;
    /**
     * Method that get a single actor social
     * @param uuid The actor uuid
     * @param social The social name
     * @returns An new {@link RequestResult} with an specific actor social
     */
    getSocialBy(uuid: string, social: string): Promise<RequestResult<ActorSocialModel>>;
    /**
     * Method that get a single random actor social
     * @param uuid The actor uuid
     * @returns An new {@link RequestResult} with random social
     */
    getRandomSocial(uuid: string): Promise<RequestResult<ActorSocialModel>>;
    /**
     * Method to fetch from HawAPI all resources
     * @param target
     * @param filters
     * @returns An new {@link RequestResult} with body and header information
     */
    private _fetch;
    /**
     * Method to handle any request error
     * @param err The request error response
     */
    private _handleError;
    /**
     * Method to create the url using API:
     * - Url
     * - Version
     * - Target
     * - Params
     *   - Filters
     *   - Pageable
     *
     * @param target
     * @param filters
     * @param pageable
     * @returns A complete url path with all params and filters
     */
    private _getUrl;
    /**
     * Method to build the client response
     * @param body The body response from API request
     * @param headers The response header
     * @param status The response status code
     * @returns An new {@link RequestResult} with all required information
     * @throws An error if page index ({@link API_HEADER_PAGE_INDEX}) is less then 0
     */
    private _buildResult;
    /**
     * Method to handle the next/prev page index
     * @param page The current page index
     * @param increase Determine if page index will be increase or decrease
     * @returns Updated page index
     * @throws An error if page index ({@link API_HEADER_PAGE_INDEX}) is less than 0
     */
    private _handlePage;
}
